@@ -4,13 +4,16 @@
 #'   netCDF.
 #'
 #' @param filepath Character. Path to the netCDF file.
-#' @param datacubepath Character. Path to the datacube (use
-#'   [ebvcube::ebv_datacubepaths()]).
+#' @param datacubepath Character. Optional. Default: NULL. Path to the datacube
+#'   (use [ebvcube::ebv_datacubepaths()]). Alternatively, you can use the
+#'   scenario and metric argument to define which cube you want to access.
 #' @param entity Character or Integer. Default is NULL. If the structure is 3D,
 #'   the entity argument is set to NULL. Else, a character string or single
 #'   integer value must indicate the entity of the 4D structure of the EBV
 #'   netCDFs.
-#' @param timestep Integer. Choose one timestep.
+#' @param timestep Integer or character. Select a timestep. Either provide an
+#'   integer value that refers to the index of the timestep (minimum value: 1)
+#'   or provide a date in ISO format, such as '2015-01-01'.
 #' @param countries Logical. Default: TRUE. Simple country outlines will be
 #'   plotted on top of the raster data. Disable by setting this option to FALSE.
 #' @param col_rev Logical. Default: FALSE Set to TRUE if you want the color ramp
@@ -18,6 +21,16 @@
 #' @param classes Integer. Default: 5. Define the amount of classes (quantiles)
 #'   for the symbology. Currently restricted to maximum 11 classes (allowed
 #'   maximum for palette RdYlBu is 11).
+#' @param scenario Character or integer. Optional. Default: NULL. Define the
+#'   scenario you want to access. If the EBV netCDF has no scenarios, leave the
+#'   default value (NULL). You can use an integer value defining the scenario or
+#'   give the name of the scenario as a character string. To check the available
+#'   scenarios and their name or number (integer), use
+#'   [ebvcube::ebv_datacubepaths()].
+#' @param metric Character or integer. Optional. Define the metric you want to
+#'   access. You can use an integer value defining the metric or give the name
+#'   of the scenario as a character string. To check the available metrics and
+#'   their name or number (integer), use [ebvcube::ebv_datacubepaths()].
 #' @param all_data Logical. Default: FALSE. The quantiles are based on the one
 #'   timestep you chose (default). If you want include the full data of the
 #'   datacube to produce several maps that are based on the same color scale,
@@ -40,11 +53,14 @@
 #'
 #' #plot a map for the 3rd timestep, divide into 7 classes
 #' ebv_map(filepath = file, datacubepath = datacubes[1,1], entity = 1,
-#'         timestep = 3, classes = 7)
+#'         timestep = 3, classes = 7, verbose = FALSE)
+#' ebv_map(filepath = file, entity = 'all bird species', timestep = "1950-01-01",
+#'         metric = 'Relative change in the number of species (%)',
+#'         classes = 7, verbose = FALSE)
 #' }
-ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =TRUE,
-                    col_rev=FALSE, classes = 5, all_data = FALSE, ignore_RAM=FALSE,
-                    verbose=TRUE){
+ebv_map <- function(filepath, datacubepath = NULL, entity=NULL, timestep=1, countries =TRUE,
+                    col_rev=FALSE, classes = 5, scenario = NULL, metric = NULL,
+                    all_data = FALSE, ignore_RAM=FALSE, verbose=TRUE){
   # start initial tests ----
   # ensure file and all datahandles are closed on exit
   withr::defer(
@@ -68,12 +84,9 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
   if(missing(filepath)){
     stop('Filepath argument is missing.')
   }
-  if(missing(datacubepath)){
-    stop('Datacubepath argument is missing.')
-  }
 
   #check verbose
-  if(checkmate::checkLogical(verbose, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(verbose, len=1, any.missing=FALSE) != TRUE){
     stop('Verbose must be of type logical.')
   }
 
@@ -89,28 +102,41 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
   }
 
   #datacubepath check
-  hdf <- rhdf5::H5Fopen(filepath, flags = "H5F_ACC_RDONLY")
-  if (rhdf5::H5Lexists(hdf, datacubepath)==FALSE | !stringr::str_detect(datacubepath, 'ebv_cube')){
-    stop(paste0('The given datacubepath is not valid:\n', datacubepath))
+  #1. make sure anything is defined
+  if(is.null(datacubepath) && is.null(scenario) && is.null(metric)){
+    stop('You need to define the datacubepath or the scenario and metric.
+       Regarding the second option: If your EBV netCDF has no scenario,
+       leave the argument empty.')
+  }else if(!is.null(datacubepath)){
+    #2. check datacubepath
+    # open file
+    hdf <- rhdf5::H5Fopen(filepath, flags = "H5F_ACC_RDONLY")
+    if (checkmate::checkCharacter(datacubepath) != TRUE) {
+      stop('Datacubepath must be of type character.')
+    }
+    if (rhdf5::H5Lexists(hdf, datacubepath) == FALSE ||
+        !stringr::str_detect(datacubepath, 'ebv_cube')) {
+      stop(paste0('The given datacubepath is not valid:\n', datacubepath))
+    }
+    #close file
+    rhdf5::H5Fclose(hdf)
+  } else if(!is.null(metric)){
+    #3. check metric&scenario
+    datacubepaths <- ebv_datacubepaths(filepath, verbose=verbose)
+    datacubepath <- ebv_i_datacubepath(scenario, metric,
+                                       datacubepaths, verbose=verbose)
   }
-  rhdf5::H5Fclose(hdf)
 
   #get properties
-  prop <- ebv_properties(filepath, datacubepath, verbose)
+  prop <- ebv_properties(filepath, datacubepath, verbose=verbose)
 
   #timestep check
-  #check if timestep is valid type
-  if (checkmate::checkInt(timestep)!=TRUE){
-    stop('The argument timestep must be of type "single integerish value"')
-  }
-
-  #check timestep range
-  min_time <- 1
-  max_time <- prop@spatial$dimensions[3]
-  if(checkmate::checkInt(timestep, lower=min_time, upper=max_time)!= TRUE){
-    stop(paste0('Chosen timestep ', timestep, ' is out of bounds. Timestep range is ',
-                min_time, ' to ', max_time, '.'))
+  #additional check because map only allows 1 timestep
+  if (length(timestep)>1){
+    stop('Please provide a single timestep.')
   }
+  #normal timestep checks -> in case of ISO, get index
+  timestep <- ebv_i_date(timestep, prop@temporal$dates)
 
   #check classes argument - single integer
   if (checkmate::checkInt(classes)!=TRUE){
@@ -121,20 +147,19 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
   }
 
   #check logical arguments
-  if(checkmate::checkLogical(ignore_RAM, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(ignore_RAM, len=1, any.missing=FALSE) != TRUE){
     stop('ignore_RAM must be of type logical.')
   }
-  if(checkmate::checkLogical(countries, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(countries, len=1, any.missing=FALSE) != TRUE){
     stop('countries must be of type logical.')
   }
-  if(checkmate::checkLogical(col_rev, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(col_rev, len=1, any.missing=FALSE) != TRUE){
     stop('col_rev must be of type logical.')
   }
 
   # end initial tests ----
 
   #get properties ----
-  fillvalue <- prop@ebv_cube$fillvalue[1]
   type.short <- ebv_i_type_r(prop@ebv_cube$type)
   title <- prop@general$title
   epsg <- prop@spatial$epsg
@@ -222,7 +247,7 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
   temp.map <- results[[2]]
 
   #reduce data.all if resampling took place and not all timesteps are needed for quantiles
-  if(!is.null(temp.map) & !all_data){
+  if(!is.null(temp.map) && !all_data){
     data.all <- terra::as.array(terra::rast(temp.map))
   }
   #get dimensions of array
@@ -237,7 +262,7 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
   }else if(length(dims)==2){
     size <- dims[1]*dims[2]
   }
-  if (size > 100000000 & verbose){
+  if (size > 100000000 && verbose){
     print('Wow that is huge! Maybe get a tea, the caluculation will take a while...')
   }
 
@@ -245,23 +270,23 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
   s <- stats::quantile(data.all, probs = seq(0, 1, (1/classes)), na.rm=TRUE)
 
   #check if quantile list values are unique
-  if(length(unique(s)) != (classes+1) & classes!=1){
+  if(length(unique(s)) != (classes+1) && classes!=1){
     message('Color Scale will be corrupted. Most likely you will see less classes than you defined.')
     s <- unique(s)
     if(length(s)==1){
-      rast_value = as.numeric(s[length(s)])
+      rast_value <- as.numeric(s[length(s)])
       legend_lab <- as.numeric(s[length(s)])
     }
   } else if (classes==1){
     if(s[1]!=s[2]){
-      s <- signif(max(data.all, na.rm=T),4)
+      s <- signif(max(data.all, na.rm=TRUE),4)
       data.raster[!is.na(data.raster)] <- 1
-      min_val <- signif(min(data.all, na.rm=T),4)
-      max_val <- signif(max(data.all, na.rm=T),4)
+      min_val <- signif(min(data.all, na.rm=TRUE),4)
+      max_val <- signif(max(data.all, na.rm=TRUE),4)
       legend_lab <- paste0(min_val, ' - ', max_val)
       rast_value <- 1
     }else{
-      rast_value = as.numeric(s[length(s)])
+      rast_value <- as.numeric(s[length(s)])
       legend_lab <- as.numeric(s[length(s)])
     }
   }
@@ -275,7 +300,7 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
 
   #get correct colors ----
 
-  if (min(s)<0 & max(s)>0){
+  if (min(s)<0 && max(s)>0){
     palette <- 'RdYlBu'
   } else {
     palette <- 'YlGn'
@@ -293,12 +318,12 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
 
 
   #define color options ----
-  if(classes==1 | length(s)==1){
-    data.raster = terra::as.factor(data.raster)
+  if(classes==1 || length(s)==1){
+    data.raster <- terra::as.factor(data.raster)
     levels(data.raster) <- data.frame(value=rast_value, desc=c('aquamarine4'))
-    color_def = ggplot2::scale_fill_manual(paste(strwrap(units,width = 10), collapse = "\n"),
+    color_def <- ggplot2::scale_fill_manual(paste(strwrap(units,width = 10), collapse = "\n"),
                                            values = c('aquamarine4'), label= legend_lab,
-                                           na.value=NA, na.translate = F
+                                           na.value=NA, na.translate = FALSE
                                            )
 
 
@@ -307,15 +332,10 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
                                                breaks =  as.numeric(s),
                                               label = signif(as.numeric(s),3),
                                               direction = direction,
-                                              guide=ggplot2::guide_bins(title=paste(strwrap(
-                                                                          units,
-                                                                          width = 10
-                                                                        ), collapse = "\n"),
-                                                                        #even.steps = FALSE,
-                                                                        #show.limits = TRUE,
-                                                                        reverse=T,
-                                                                        axis=F
-                                                                        )
+                                              name = paste(strwrap(
+                                                units,
+                                                width = 10
+                                              ), collapse = "\n")
                                               )
   }
 
@@ -330,7 +350,7 @@ ebv_map <- function(filepath, datacubepath, entity=NULL, timestep=1, countries =
 
     #crop world_boundaries to extent
     extent <- terra::ext(data.raster)
-    world_boundaries <- terra::crop(world_boundaries, extent )
+    world_boundaries <- terra::crop(world_boundaries, extent)
 
     print(
       ggplot2::ggplot() +
