@@ -6,11 +6,10 @@
 #'   publisher_institution, publisher_email, comment, keywords, id, history,
 #'   licence, conventions, naming_authority, date_created, date_issued,
 #'   entity_names, entity_type, entity_scope, entity_classification_name,
-#'   entity_classification_url
+#'   entity_classification_url, taxonomy, taxonomy_lsid
 #' @slot spatial Named list. Elements: wkt2, epsg, extent, resolution,
 #'   crs_units, dimensions, scope, description
-#' @slot temporal Named list. Elements: resolution, units, timesteps,
-#'   dates
+#' @slot temporal Named list. Elements: resolution, units, timesteps, dates
 #' @slot metric Named list. Elements: name, description
 #' @slot scenario Named list. Elements: name, description
 #' @slot ebv_cube Named list. Elements: units, coverage_content_type, fillvalue,
@@ -22,7 +21,9 @@
 #' @note If the properties class holds e.g. no scenario information this is
 #'   indicated with an element called status in the list. \cr If you read an EBV
 #'   netCDF based on an older standard, the properties will differ from the
-#'   definition above.
+#'   definition above. If the dataset does not encompass taxonomic info, the
+#'   'taxonomy' is NA. Besides, even if a dataset encompasses the taxonomy
+#'   information, the 'taxonomy_lsid' can be NA.
 methods::setClass(
   "EBV netCDF properties",
   slots = list(
@@ -40,29 +41,46 @@ methods::setClass(
 #' @description Structured access to all attributes of the netCDF file.
 #'
 #' @param filepath Character. Path to the netCDF file.
-#' @param datacubepath Character. Optional. Path to the datacube (use
-#'   [ebvcube::ebv_datacubepaths()]).
+#' @param datacubepath Character. Optional. Default: NULL. Path to the datacube
+#'   (use [ebvcube::ebv_datacubepaths()]). Alternatively, you can use the
+#'   scenario and metric argument to define which cube you want to access.
 #' @param verbose Logical. Default: TRUE. Turn off additional prints by setting
 #'   it to FALSE.
+#' @param scenario Character or integer. Optional. Default: NULL. Define the
+#'   scenario you want to access. If the EBV netCDF has no scenarios, leave the
+#'   default value (NULL). You can use an integer value defining the scenario or
+#'   give the name of the scenario as a character string. To check the available
+#'   scenarios and their name or number (integer), use
+#'   [ebvcube::ebv_datacubepaths()].
+#' @param metric Character or integer. Optional. Define the metric you want to
+#'   access. You can use an integer value defining the metric or give the name
+#'   of the scenario as a character string. To check the available metrics and
+#'   their name or number (integer), use [ebvcube::ebv_datacubepaths()].
 #'
 #' @return S4 class containing information about file or file and datacube
 #'   depending on input.
 #' @export
 #'
 #' @examples
-#' #set path to EBV netCDF
+#' #define path to EBV netCDF
 #' file <- system.file(file.path("extdata","martins_comcom_subset.nc"), package="ebvcube")
 #' #get all datacubepaths of EBV netCDF
 #' datacubes <- ebv_datacubepaths(file, verbose=FALSE)
 #'
 #' #get properties only for the file
 #' prop_file <- ebv_properties(file)
-#' #get properties for the file and a specific datacube
-#' prop_dc <- ebv_properties(file, datacubes[1,1])
+#' #get properties for the file and a specific datacube - use datacubepath
+#' prop_dc <- ebv_properties(file, datacubepath = datacubes[1,1])
+#' #get properties for the file and a specific datacube - use scenario & metric
+#' #note: this dataset has no scenario -> only metric is defined
+#' prop_dc <- ebv_properties(file, metric = 2)
 ebv_properties <-
   function(filepath,
            datacubepath = NULL,
+           scenario = NULL,
+           metric = NULL,
            verbose = TRUE) {
+
     ####initial tests start ----
     # ensure file and all datahandles are closed on exit
     withr::defer(if (exists('hdf')) {
@@ -71,13 +89,23 @@ ebv_properties <-
       }
     })
 
+    dids <- c('entity_list', 'did', 'entity_level.id')
+    withr::defer(
+      for (id in dids){
+        if(exists(id)){
+          id <- eval(parse(text = id))
+          if(rhdf5::H5Iis_valid(id)==TRUE){rhdf5::H5Dclose(id)}
+        }
+      }
+    )
+
     #are all arguments given?
     if (missing(filepath)) {
       stop('Filepath argument is missing.')
     }
 
     #check verbose
-    if (checkmate::checkLogical(verbose, len = 1, any.missing = F) != TRUE) {
+    if (checkmate::checkLogical(verbose, len = 1, any.missing = FALSE) != TRUE) {
       stop('Verbose must be of type logical.')
     }
 
@@ -92,33 +120,72 @@ ebv_properties <-
       stop(paste0('File ending is wrong. File cannot be processed.'))
     }
 
-    # open file
-    hdf <- rhdf5::H5Fopen(filepath, flags = "H5F_ACC_RDONLY")
-
-    #variable check
-    if (checkmate::checkCharacter(datacubepath) != TRUE &
-        !is.null(datacubepath)) {
-      stop('Datacubepath must be of type character.')
-    }
-    if (!is.null(datacubepath)) {
-      if (rhdf5::H5Lexists(hdf, datacubepath) == FALSE |
+    #datacubepath check
+    #1. make sure anything is defined
+    if(is.null(datacubepath) && is.null(scenario) && is.null(metric)){
+      if(verbose){
+        print('Giving the properties for the file. For more info on a specific datacube, define the metric and scenario OR datacubepath.')
+      }
+      # open file
+      hdf <- rhdf5::H5Fopen(filepath, flags = "H5F_ACC_RDONLY")
+    }else if(!is.null(datacubepath)){
+    #2. check datacubepath
+      # open file
+      hdf <- rhdf5::H5Fopen(filepath, flags = "H5F_ACC_RDONLY")
+      if (checkmate::checkCharacter(datacubepath) != TRUE) {
+        stop('Datacubepath must be of type character.')
+      }
+      if (rhdf5::H5Lexists(hdf, datacubepath) == FALSE ||
           !stringr::str_detect(datacubepath, 'ebv_cube')) {
-        stop(paste0('The given variable is not valid:\n', datacubepath))
+        stop(paste0('The given datacubepath is not valid:\n', datacubepath))
+      }
+      if(verbose){
+        print('Giving the properties for the file and a specified datacube.')
+      }
+    } else if(!is.null(metric)){
+      #3. check metric&scenario
+      datacubepaths <- ebv_datacubepaths(filepath, verbose)
+      datacubepath <- ebv_i_datacubepath(scenario, metric,
+                                         datacubepaths, verbose)
+      # open file
+      hdf <- rhdf5::H5Fopen(filepath, flags = "H5F_ACC_RDONLY")
+
+      if(verbose){
+        print('Giving the properties for the file and a specified datacube.')
       }
     }
+
     ####initial tests end ----
 
-    #check dimensions
-    dump <- rhdf5::h5dump(hdf, load=FALSE, recursive=FALSE)
+    #get all taxonomy values----
+    if(rhdf5::H5Lexists(hdf, 'entity_list')){
+      #get levels
+      tax_levels <- suppressWarnings(rhdf5::h5read(hdf, 'entity_levels'))
+      tax_levels <- apply(tax_levels, 1, ebv_i_paste)
 
-    #check structure
-    if('entity' %in% names(dump)){
-      new <- TRUE
-    } else{
-      new <- FALSE
+      #get values of all levels
+      tax_list <- suppressWarnings(rhdf5::h5read(hdf, 'entity_list'))
+      #create taxon table
+      dims_list <- dim(tax_list)
+      taxon_df <- data.frame(matrix(NA, nrow=dims_list[2], ncol=length(tax_levels)))
+      colnames(taxon_df) <- tax_levels
+      for (d in 1:dims_list[1]){
+        taxon_df[,d] <- apply(tax_list[d,,], 1, ebv_i_paste)
+      }
+
+      #check for lsid
+      if(rhdf5::H5Lexists(hdf, 'entity_lsid')){
+        lsid_list <- suppressWarnings(rhdf5::h5read(hdf, 'entity_lsid'))
+        taxon_lsid <- apply(lsid_list, 1, ebv_i_paste)
+      } else{
+        taxon_lsid <- NA
+      }
+
+    }else{
+      taxon_df <- NA
+      taxon_lsid <- NA
     }
 
-    #ACDD STANDARD----
     #get all entity names ----
     entity_data <- suppressWarnings(rhdf5::h5read(hdf, 'entity'))#HERE
     entity_names <- c()
@@ -128,8 +195,6 @@ ebv_properties <-
       entity_names <- entity_data
     }
 
-    time_data <- suppressWarnings(rhdf5::h5read(hdf, 'time'))
-
     #general ----
     # add entity names to global properties
     title <- ebv_i_read_att(hdf, 'title', verbose)
@@ -233,6 +298,7 @@ ebv_properties <-
     rhdf5::H5Dclose(did)
 
     # temporal ----
+    time_data <- suppressWarnings(rhdf5::h5read(hdf, 'time'))
     did <- rhdf5::H5Dopen(hdf, 'time')
     t_res <-
       ebv_i_read_att(hdf, 'time_coverage_resolution', verbose)
@@ -242,6 +308,7 @@ ebv_properties <-
 
     rhdf5::H5Dclose(did)
 
+    #create lists of attributes----
     general <-
       list(
         'title' = title,
@@ -273,7 +340,9 @@ ebv_properties <-
         'entity_type' = ebv_entity_type,
         'entity_scope' = ebv_entity_scope,
         'entity_classification_name' = ebv_entity_classification_name,
-        'entity_classification_url' = ebv_entity_classification_url
+        'entity_classification_url' = ebv_entity_classification_url,
+        'taxonomy' = taxon_df,
+        'taxonomy_lsid' = taxon_lsid
       )
     spatial <-
       list(
@@ -302,11 +371,11 @@ ebv_properties <-
         path_s <- stringr::str_split(datacubepath, '/')[[1]][1]
         gid <- rhdf5::H5Gopen(hdf, path_s)
         #global info
-        ebv_scenario_classification_name <-
+        ebv_sce_class_name <-
           ebv_i_read_att(hdf, 'ebv_scenario_classification_name', verbose)
-        ebv_scenario_classification_url <-
+        ebv_scen_class_url <-
           ebv_i_read_att(hdf, 'ebv_scenario_classification_url', verbose)
-        ebv_scenario_classification_version <-
+        ebv_sce_class_version <-
           ebv_i_read_att(hdf, 'ebv_scenario_classification_version', verbose)
         #group info
         name_s <- ebv_i_read_att(gid, 'standard_name', verbose)
@@ -316,9 +385,9 @@ ebv_properties <-
           list(
             'name' = name_s,
             'description' = description_s,
-            'scenario_classification_name' = ebv_scenario_classification_name,
-            'scenario_classification_url' = ebv_scenario_classification_url,
-            'scenario_classification_version' = ebv_scenario_classification_version
+            'scenario_classification_name' = ebv_sce_class_name,
+            'scenario_classification_url' = ebv_scen_class_url,
+            'scenario_classification_version' = ebv_sce_class_version
           )
 
         # get metric info
