@@ -6,17 +6,31 @@
 #'   useful for data that exceeds your memory.
 #'
 #' @param filepath Character. Path to the netCDF file.
-#' @param datacubepath Character. Path to the datacube (use
-#'   [ebvcube::ebv_datacubepaths()]).
+#' @param datacubepath Character. Optional. Default: NULL. Path to the datacube
+#'   (use [ebvcube::ebv_datacubepaths()]). Alternatively, you can use the
+#'   scenario and metric argument to define which cube you want to access.
 #' @param entity Character or Integer. Default is NULL. If the structure is 3D,
 #'   the entity argument is set to NULL. Else, a character string or single
 #'   integer value must indicate the entity of the 4D structure of the EBV
 #'   netCDFs.
-#' @param timestep Integer. Choose one or several timesteps (vector).
+#' @param timestep Integer or character. Select one or several timestep(s).
+#'   Either provide an integer value or list of values that refer(s) to the
+#'   index of the timestep(s) (minimum value: 1) or provide a date or list of
+#'   dates in ISO format, such as '2015-01-01'.
 #' @param type Character. Choose between 'a', 'r' and 'da'. The first returns an
 #'   array or matrix object. The 'r' indicates that a SpatRaster object from the
 #'   terra package will be returned (default). The latter ('da') returns a
 #'   DelayedArray or DelayedMatrix object.
+#' @param scenario Character or integer. Optional. Default: NULL. Define the
+#'   scenario you want to access. If the EBV netCDF has no scenarios, leave the
+#'   default value (NULL). You can use an integer value defining the scenario or
+#'   give the name of the scenario as a character string. To check the available
+#'   scenarios and their name or number (integer), use
+#'   [ebvcube::ebv_datacubepaths()].
+#' @param metric Character or integer. Optional. Define the metric you want to
+#'   access. You can use an integer value defining the metric or give the name
+#'   of the scenario as a character string. To check the available metrics and
+#'   their name or number (integer), use [ebvcube::ebv_datacubepaths()].
 #' @param sparse Logical. Default: FALSE. Set to TRUE if the data contains a lot
 #'   empty raster cells. Only relevant for DelayedArray return value.
 #' @param ignore_RAM Logical. Default: FALSE. Checks if there is enough space in
@@ -46,13 +60,14 @@
 #'                               entity = 1, timestep = c(1,3), type='da',
 #'                               sparse = TRUE)
 #' #read data as SpatRaster
-#' cSAR.raster <- ebv_read(filepath = file, datacubepath = datacubes[1,1],
-#'                              entity = 1, timestep = 1:3, type='r')
+#' cSAR.raster <- ebv_read(filepath = file,entity = 1, timestep = "2000-01-01",
+#'                         type='r', metric = 1)
 #' #read data as Array
 #' cSAR.array <- ebv_read(filepath = file, datacubepath = datacubes[1,1],
 #'                               entity = 1, timestep = 1, type='r')
 #' }
-ebv_read <- function(filepath, datacubepath,  entity=NULL, timestep=1, type='r',
+ebv_read <- function(filepath, datacubepath = NULL,  entity=NULL, timestep=1,
+                     type='r', scenario = NULL, metric = NULL,
                      sparse=FALSE, ignore_RAM = FALSE, verbose = FALSE){
   ####initial tests start ----
   # ensure file and all datahandles are closed on exit
@@ -65,20 +80,17 @@ ebv_read <- function(filepath, datacubepath,  entity=NULL, timestep=1, type='r',
   if(missing(filepath)){
     stop('Filepath argument is missing.')
   }
-  if(missing(datacubepath)){
-    stop('Datacubepath argument is missing.')
-  }
 
   #check verbose
-  if(checkmate::checkLogical(verbose, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(verbose, len=1, any.missing=FALSE) != TRUE){
     stop('Verbose must be of type logical.')
   }
 
   #check logical arguments
-  if(checkmate::checkLogical(sparse, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(sparse, len=1, any.missing=FALSE) != TRUE){
     stop('sparse must be of type logical.')
   }
-  if(checkmate::checkLogical(ignore_RAM, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(ignore_RAM, len=1, any.missing=FALSE) != TRUE){
     stop('ignore_RAM must be of type logical.')
   }
 
@@ -104,18 +116,34 @@ ebv_read <- function(filepath, datacubepath,  entity=NULL, timestep=1, type='r',
   #file closed?
   # ebv_i_file_opened(filepath, verbose)
 
-  #variable check
-  if (checkmate::checkCharacter(datacubepath) != TRUE){
-    stop('Datacubepath must be of type character.')
+  #datacubepath check
+  #1. make sure anything is defined
+  if(is.null(datacubepath) && is.null(scenario) && is.null(metric)){
+    stop('You need to define the datacubepath or the scenario and metric.
+       Regarding the second option: If your EBV netCDF has no scenario,
+       leave the argument empty.')
+  }else if(!is.null(datacubepath)){
+    #2. check datacubepath
+    # open file
+    hdf <- rhdf5::H5Fopen(filepath, flags = "H5F_ACC_RDONLY")
+    if (checkmate::checkCharacter(datacubepath) != TRUE) {
+      stop('Datacubepath must be of type character.')
+    }
+    if (rhdf5::H5Lexists(hdf, datacubepath) == FALSE ||
+        !stringr::str_detect(datacubepath, 'ebv_cube')) {
+      stop(paste0('The given datacubepath is not valid:\n', datacubepath))
+    }
+    #close file
+    rhdf5::H5Fclose(hdf)
+  } else if(!is.null(metric)){
+    #3. check metric&scenario
+    datacubepaths <- ebv_datacubepaths(filepath, verbose=verbose)
+    datacubepath <- ebv_i_datacubepath(scenario, metric,
+                                       datacubepaths, verbose=verbose)
   }
-  hdf <- rhdf5::H5Fopen(filepath, flags = 'H5F_ACC_RDONLY')
-  if (rhdf5::H5Lexists(hdf, datacubepath)==FALSE | !stringr::str_detect(datacubepath, 'ebv_cube')){
-    stop(paste0('The given datacubepath is not valid:\n', datacubepath))
-  }
-  rhdf5::H5Fclose(hdf)
 
   #get properties
-  prop <- ebv_properties(filepath, datacubepath, verbose)
+  prop <- ebv_properties(filepath, datacubepath, verbose=verbose)
 
   #check file structure
   is_4D <- ebv_i_4D(filepath)
@@ -137,18 +165,8 @@ ebv_read <- function(filepath, datacubepath,  entity=NULL, timestep=1, type='r',
     }
   }
 
-  #timestep check
-  #check if timestep is valid type
-  if(checkmate::checkIntegerish(timestep) != TRUE){
-    stop('Timestep has to be an integer or a list of integers.')
-  }
-
-  #check timestep range
-  max_time <- prop@spatial$dimensions[3]
-  min_time <- 1
-  if(checkmate::checkIntegerish(timestep, lower=min_time, upper=max_time) != TRUE){
-    stop(paste0('Chosen timestep ', paste(timestep, collapse = ' '), ' is out of bounds. Timestep range is ', min_time, ' to ', max_time, '.'))
-  }
+  #timestep check -> in case of ISO, get index
+  timestep <- ebv_i_date(timestep, prop@temporal$dates)
 
   #######initial test end ----
 
@@ -203,7 +221,7 @@ ebv_read <- function(filepath, datacubepath,  entity=NULL, timestep=1, type='r',
     }
 
     # return any in-memory object ----
-  } else if (type=='a' | type=='r') {
+  } else if (type=='a' || type=='r') {
     #check needed RAM
     if (!ignore_RAM){
       type.long <- prop@ebv_cube$type
