@@ -5,23 +5,37 @@
 #'
 #' @param filepath_src Character. Path to the netCDF file whose resolution
 #'   should be changed.
-#' @param datacubepath_src Character. Path to the datacube (use
-#'   [ebvcube::ebv_datacubepaths()]) whose resolution should be changed.
+#' @param datacubepath_src Character. Optional. Default: NULL. Path to the
+#'   datacube (use [ebvcube::ebv_datacubepaths()]). Alternatively, you can use
+#'   the scenario and metric argument to define which cube you want to access.
 #' @param entity_src Character or Integer. Default is NULL. If the structure is
 #'   3D, the entity argument is set to NULL. Else, a character string or single
 #'   integer value must indicate the entity of the 4D structure of the EBV
 #'   netCDFs.
-#' @param resolution Either the path to an EBV netCDF file that determines the
-#'   resolution (character) or the resolution defined directly (numeric). The
-#'   vector defining the resolution directly must contain three elements: the
-#'   x-resolution, the y-resolution and the corresponding EPSG code, e.g.
-#'   c(0.25, 0.25, 4326).
+#' @param resolution Character or Numeric. Either the path to an EBV netCDF file
+#'   that determines the resolution (character) or the resolution defined
+#'   directly (numeric). The vector defining the resolution directly must
+#'   contain three elements: the x-resolution, the y-resolution and the
+#'   corresponding EPSG code, e.g. c(0.25, 0.25, 4326).
 #' @param outputpath Character. Set path to write data as GeoTiff on disk.
-#' @param timestep_src Integer. Choose one or several timesteps (vector).
+#' @param timestep_src Integer or character. Select one or several timestep(s).
+#'   Either provide an integer value or list of values that refer(s) to the
+#'   index of the timestep(s) (minimum value: 1) or provide a date or list of
+#'   dates in ISO format, such as '2015-01-01'.
 #' @param method Character. Default: bilinear. Define resampling method. Choose
 #'   from: "near","bilinear","cubic", "cubicspline", "lanczos", "sum", "min",
 #'   "q1", "med", "q3", "max", "average", "mode" and "rms". For categorical
 #'   data, use 'near'. Based on [terra::project()].
+#' @param scenario Character or integer. Optional. Default: NULL. Define the
+#'   scenario you want to access. If the EBV netCDF has no scenarios, leave the
+#'   default value (NULL). You can use an integer value defining the scenario or
+#'   give the name of the scenario as a character string. To check the available
+#'   scenarios and their name or number (integer), use
+#'   [ebvcube::ebv_datacubepaths()].
+#' @param metric Character or integer. Optional. Define the metric you want to
+#'   access. You can use an integer value defining the metric or give the name
+#'   of the scenario as a character string. To check the available metrics and
+#'   their name or number (integer), use [ebvcube::ebv_datacubepaths()].
 #' @param return_raster Logical. Default: FALSE. Set to TRUE to directly get the
 #'   corresponding SpatRaster object.
 #' @param overwrite Logical. Default: FALSE. Set to TRUE to overwrite the output
@@ -61,8 +75,9 @@
 #'              outputpath = out, overwrite=TRUE)
 #'
 #' }
-ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timestep_src = 1,
-                         resolution, outputpath, method='bilinear', return_raster=FALSE,
+ebv_resample <- function(filepath_src, datacubepath_src = NULL, entity_src=NULL,
+                         timestep_src = 1, resolution, outputpath, method='bilinear',
+                         scenario = NULL, metric = NULL, return_raster=FALSE,
                          overwrite = FALSE, ignore_RAM=FALSE, verbose=TRUE){
   ####initial tests start ----
   # ensure file and all datahandles are closed on exit
@@ -76,9 +91,6 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
   if(missing(filepath_src)){
     stop('Filepath_src argument is missing.')
   }
-  if(missing(datacubepath_src)){
-    stop('Datacubepath_src argument is missing.')
-  }
   if(missing(resolution)){
     stop('Resolution argument is missing.')
   }
@@ -87,18 +99,18 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
   }
 
   #check verbose
-  if(checkmate::checkLogical(verbose, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(verbose, len=1, any.missing=FALSE) != TRUE){
     stop('Verbose must be of type logical.')
   }
 
   #check logical arguments
-  if(checkmate::checkLogical(return_raster, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(return_raster, len=1, any.missing=FALSE) != TRUE){
     stop('return_raster must be of type logical.')
   }
-  if(checkmate::checkLogical(overwrite, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(overwrite, len=1, any.missing=FALSE) != TRUE){
     stop('overwrite must be of type logical.')
   }
-  if(checkmate::checkLogical(ignore_RAM, len=1, any.missing=F) != TRUE){
+  if(checkmate::checkLogical(ignore_RAM, len=1, any.missing=FALSE) != TRUE){
     stop('ignore_RAM must be of type logical.')
   }
 
@@ -133,13 +145,13 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
   if(!is.null(filepath_dest)){
     #filepath dest check
     if (checkmate::checkCharacter(filepath_dest) != TRUE){
-      stop('Filepath_dest must be of type character.')
+      stop('Resolution must be of type integer or character.')
     }
     if (checkmate::checkFileExists(filepath_dest) != TRUE){
-      stop(paste0('Filepath_dest does not exist.\n', filepath_dest))
+      stop(paste0('The file for the resolution does not exist.\n', filepath_dest))
     }
     if (!endsWith(filepath_dest, '.nc')){
-      stop(paste0('File ending of filepath_dest is wrong. File cannot be processed.'))
+      stop(paste0('File ending of the resolution-file is wrong - must be .nc'))
     }
 
     #get properties
@@ -154,18 +166,34 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
 
   }
 
-  #source variable check
-  if (checkmate::checkCharacter(datacubepath_src) != TRUE){
-    stop('Datacubepath must be of type character.')
+  #source datacubepath check
+  #1. make sure anything is defined
+  if(is.null(datacubepath_src) && is.null(scenario) && is.null(metric)){
+    stop('You need to define the datacubepath_src or the scenario and metric.
+       Regarding the second option: If your EBV netCDF has no scenario,
+       leave the argument empty.')
+  }else if(!is.null(datacubepath_src)){
+    #2. check datacubepath_src
+    # open file
+    hdf <- rhdf5::H5Fopen(filepath_src, flags = "H5F_ACC_RDONLY")
+    if (checkmate::checkCharacter(datacubepath_src) != TRUE) {
+      stop('Datacubepath must be of type character.')
+    }
+    if (rhdf5::H5Lexists(hdf, datacubepath_src) == FALSE ||
+        !stringr::str_detect(datacubepath_src, 'ebv_cube')) {
+      stop(paste0('The given datacubepath_src is not valid:\n', datacubepath_src))
+    }
+    #close file
+    rhdf5::H5Fclose(hdf)
+  } else if(!is.null(metric)){
+    #3. check metric&scenario
+    datacubepaths <- ebv_datacubepaths(filepath_src, verbose=verbose)
+    datacubepath_src <- ebv_i_datacubepath(scenario, metric,
+                                       datacubepaths, verbose=verbose)
   }
-  hdf <- rhdf5::H5Fopen(filepath_src, flags = "H5F_ACC_RDONLY")
-  if (rhdf5::H5Lexists(hdf, datacubepath_src)==FALSE | !stringr::str_detect(datacubepath_src, 'ebv_cube')){
-    stop(paste0('The given variable is not valid:\n', datacubepath_src))
-  }
-  rhdf5::H5Fclose(hdf)
 
   #get properties source
-  prop_src <- ebv_properties(filepath_src, datacubepath_src, verbose)
+  prop_src <- ebv_properties(filepath_src, datacubepath_src,  verbose=verbose)
   type.long <- prop_src@ebv_cube$type
   entity_names <- prop_src@general$entity_names
   extent_src <- prop_src@spatial$extent
@@ -189,18 +217,8 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
     }
   }
 
-  #source timestep check
-  #check if timestep is valid type
-  if(checkmate::checkIntegerish(timestep_src) != TRUE){
-    stop('timestep_src has to be an integer or a list of integers.')
-  }
-
-  #check timestep_src range
-  max_time <- prop_src@spatial$dimensions[3]
-  min_time <- 1
-  if(checkmate::checkIntegerish(timestep_src, lower=min_time, upper=max_time) != TRUE){
-    stop(paste0('Chosen timestep_src ', paste(timestep_src, collapse = ' '), ' is out of bounds. timestep_src range is ', min_time, ' to ', max_time, '.'))
-  }
+  #timestep check -> in case of ISO, get index
+  timestep_src <- ebv_i_date(timestep_src, prop_src@temporal$dates)
 
   #outputpath check
   if (!is.null(outputpath)){
@@ -247,10 +265,6 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
 
   #######initial test end ----
 
-  #srs defintion from epsg
-  srs_src <- paste0('EPSG:',epsg_src)
-  srs_dest <- paste0('EPSG:',epsg_dest)
-
   #get output type
   type_ot <- ebv_i_type_ot(type.long)
   type_terra <- ebv_i_type_terra(type_ot)
@@ -260,6 +274,7 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
   data_raw <- terra::rast(filepath_src, subds = paste0('/', datacubepath_src))
 
   #get the index depending on the amount of entities and timesteps
+  max_time <- prop_src@spatial$dimensions[3]
   terra_index <- (entity_index-1)*max_time + timestep_src
   data_ts <- data_raw[[terra_index]]
 
@@ -290,7 +305,7 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
   #align to origin of the destination file
   data_proj <- tryCatch(
     {
-      data_proj <- terra::project(data_ts, y = dummy, align=T, method=method, gdal=T)
+      data_proj <- terra::project(data_ts, y = dummy, align=TRUE, method=method, gdal=TRUE)
     },
     error=function(e){
       # if (!stringr::str_detect(e, 'cannot create dataset from source')){
@@ -300,7 +315,7 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
         message('Slower algorithm needs to be used. Please be patient.')
       }
 
-      data_proj <- terra::project(data_ts, y = dummy, align=T, method=method, gdal=F)
+      data_proj <- terra::project(data_ts, y = dummy, align=TRUE, method=method, gdal=FALSE)
     }
   )
 
@@ -316,4 +331,3 @@ ebv_resample <- function(filepath_src, datacubepath_src, entity_src=NULL, timest
     return(outputpath)
   }
 }
-
